# coding: utf-8

# flake8: noqa

"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from mtmaisdk.clients.rest.api.api_token_api import APITokenApi
from mtmaisdk.clients.rest.api.event_api import EventApi
from mtmaisdk.clients.rest.api.github_api import GithubApi
from mtmaisdk.clients.rest.api.healthcheck_api import HealthcheckApi
from mtmaisdk.clients.rest.api.log_api import LogApi
from mtmaisdk.clients.rest.api.metadata_api import MetadataApi
from mtmaisdk.clients.rest.api.rate_limits_api import RateLimitsApi
from mtmaisdk.clients.rest.api.sns_api import SNSApi
from mtmaisdk.clients.rest.api.slack_api import SlackApi
from mtmaisdk.clients.rest.api.step_run_api import StepRunApi
from mtmaisdk.clients.rest.api.tenant_api import TenantApi
from mtmaisdk.clients.rest.api.user_api import UserApi
from mtmaisdk.clients.rest.api.worker_api import WorkerApi
from mtmaisdk.clients.rest.api.workflow_api import WorkflowApi
from mtmaisdk.clients.rest.api.workflow_run_api import WorkflowRunApi
from mtmaisdk.clients.rest.api.default_api import DefaultApi

# import ApiClient
from mtmaisdk.clients.rest.api_response import ApiResponse
from mtmaisdk.clients.rest.api_client import ApiClient
from mtmaisdk.clients.rest.configuration import Configuration
from mtmaisdk.clients.rest.exceptions import OpenApiException
from mtmaisdk.clients.rest.exceptions import ApiTypeError
from mtmaisdk.clients.rest.exceptions import ApiValueError
from mtmaisdk.clients.rest.exceptions import ApiKeyError
from mtmaisdk.clients.rest.exceptions import ApiAttributeError
from mtmaisdk.clients.rest.exceptions import ApiException

# import models into sdk package
from mtmaisdk.clients.rest.models.api_error import APIError
from mtmaisdk.clients.rest.models.api_errors import APIErrors
from mtmaisdk.clients.rest.models.api_meta import APIMeta
from mtmaisdk.clients.rest.models.api_meta_auth import APIMetaAuth
from mtmaisdk.clients.rest.models.api_meta_integration import APIMetaIntegration
from mtmaisdk.clients.rest.models.api_meta_posthog import APIMetaPosthog
from mtmaisdk.clients.rest.models.api_resource_meta import APIResourceMeta
from mtmaisdk.clients.rest.models.api_token import APIToken
from mtmaisdk.clients.rest.models.accept_invite_request import AcceptInviteRequest
from mtmaisdk.clients.rest.models.bulk_create_event_request import BulkCreateEventRequest
from mtmaisdk.clients.rest.models.bulk_create_event_response import BulkCreateEventResponse
from mtmaisdk.clients.rest.models.cancel_event_request import CancelEventRequest
from mtmaisdk.clients.rest.models.create_api_token_request import CreateAPITokenRequest
from mtmaisdk.clients.rest.models.create_api_token_response import CreateAPITokenResponse
from mtmaisdk.clients.rest.models.create_event_request import CreateEventRequest
from mtmaisdk.clients.rest.models.create_pull_request_from_step_run import CreatePullRequestFromStepRun
from mtmaisdk.clients.rest.models.create_sns_integration_request import CreateSNSIntegrationRequest
from mtmaisdk.clients.rest.models.create_tenant_alert_email_group_request import CreateTenantAlertEmailGroupRequest
from mtmaisdk.clients.rest.models.create_tenant_invite_request import CreateTenantInviteRequest
from mtmaisdk.clients.rest.models.create_tenant_request import CreateTenantRequest
from mtmaisdk.clients.rest.models.cron_workflows import CronWorkflows
from mtmaisdk.clients.rest.models.cron_workflows_list import CronWorkflowsList
from mtmaisdk.clients.rest.models.cron_workflows_order_by_field import CronWorkflowsOrderByField
from mtmaisdk.clients.rest.models.event import Event
from mtmaisdk.clients.rest.models.event_data import EventData
from mtmaisdk.clients.rest.models.event_key_list import EventKeyList
from mtmaisdk.clients.rest.models.event_list import EventList
from mtmaisdk.clients.rest.models.event_order_by_direction import EventOrderByDirection
from mtmaisdk.clients.rest.models.event_order_by_field import EventOrderByField
from mtmaisdk.clients.rest.models.event_update_cancel200_response import EventUpdateCancel200Response
from mtmaisdk.clients.rest.models.event_workflow_run_summary import EventWorkflowRunSummary
from mtmaisdk.clients.rest.models.get_step_run_diff_response import GetStepRunDiffResponse
from mtmaisdk.clients.rest.models.job import Job
from mtmaisdk.clients.rest.models.job_run import JobRun
from mtmaisdk.clients.rest.models.job_run_status import JobRunStatus
from mtmaisdk.clients.rest.models.list_api_tokens_response import ListAPITokensResponse
from mtmaisdk.clients.rest.models.list_pull_requests_response import ListPullRequestsResponse
from mtmaisdk.clients.rest.models.list_sns_integrations import ListSNSIntegrations
from mtmaisdk.clients.rest.models.list_slack_webhooks import ListSlackWebhooks
from mtmaisdk.clients.rest.models.log_line import LogLine
from mtmaisdk.clients.rest.models.log_line_level import LogLineLevel
from mtmaisdk.clients.rest.models.log_line_list import LogLineList
from mtmaisdk.clients.rest.models.log_line_order_by_direction import LogLineOrderByDirection
from mtmaisdk.clients.rest.models.log_line_order_by_field import LogLineOrderByField
from mtmaisdk.clients.rest.models.pagination_response import PaginationResponse
from mtmaisdk.clients.rest.models.pull_request import PullRequest
from mtmaisdk.clients.rest.models.pull_request_state import PullRequestState
from mtmaisdk.clients.rest.models.queue_metrics import QueueMetrics
from mtmaisdk.clients.rest.models.rate_limit import RateLimit
from mtmaisdk.clients.rest.models.rate_limit_list import RateLimitList
from mtmaisdk.clients.rest.models.rate_limit_order_by_direction import RateLimitOrderByDirection
from mtmaisdk.clients.rest.models.rate_limit_order_by_field import RateLimitOrderByField
from mtmaisdk.clients.rest.models.recent_step_runs import RecentStepRuns
from mtmaisdk.clients.rest.models.reject_invite_request import RejectInviteRequest
from mtmaisdk.clients.rest.models.replay_event_request import ReplayEventRequest
from mtmaisdk.clients.rest.models.replay_workflow_runs_request import ReplayWorkflowRunsRequest
from mtmaisdk.clients.rest.models.replay_workflow_runs_response import ReplayWorkflowRunsResponse
from mtmaisdk.clients.rest.models.rerun_step_run_request import RerunStepRunRequest
from mtmaisdk.clients.rest.models.sns_integration import SNSIntegration
from mtmaisdk.clients.rest.models.scheduled_run_status import ScheduledRunStatus
from mtmaisdk.clients.rest.models.scheduled_workflows import ScheduledWorkflows
from mtmaisdk.clients.rest.models.scheduled_workflows_list import ScheduledWorkflowsList
from mtmaisdk.clients.rest.models.scheduled_workflows_order_by_field import ScheduledWorkflowsOrderByField
from mtmaisdk.clients.rest.models.semaphore_slots import SemaphoreSlots
from mtmaisdk.clients.rest.models.slack_webhook import SlackWebhook
from mtmaisdk.clients.rest.models.step import Step
from mtmaisdk.clients.rest.models.step_run import StepRun
from mtmaisdk.clients.rest.models.step_run_archive import StepRunArchive
from mtmaisdk.clients.rest.models.step_run_archive_list import StepRunArchiveList
from mtmaisdk.clients.rest.models.step_run_diff import StepRunDiff
from mtmaisdk.clients.rest.models.step_run_event import StepRunEvent
from mtmaisdk.clients.rest.models.step_run_event_list import StepRunEventList
from mtmaisdk.clients.rest.models.step_run_event_reason import StepRunEventReason
from mtmaisdk.clients.rest.models.step_run_event_severity import StepRunEventSeverity
from mtmaisdk.clients.rest.models.step_run_status import StepRunStatus
from mtmaisdk.clients.rest.models.tenant import Tenant
from mtmaisdk.clients.rest.models.tenant_alert_email_group import TenantAlertEmailGroup
from mtmaisdk.clients.rest.models.tenant_alert_email_group_list import TenantAlertEmailGroupList
from mtmaisdk.clients.rest.models.tenant_alerting_settings import TenantAlertingSettings
from mtmaisdk.clients.rest.models.tenant_invite import TenantInvite
from mtmaisdk.clients.rest.models.tenant_invite_list import TenantInviteList
from mtmaisdk.clients.rest.models.tenant_list import TenantList
from mtmaisdk.clients.rest.models.tenant_member import TenantMember
from mtmaisdk.clients.rest.models.tenant_member_list import TenantMemberList
from mtmaisdk.clients.rest.models.tenant_member_role import TenantMemberRole
from mtmaisdk.clients.rest.models.tenant_queue_metrics import TenantQueueMetrics
from mtmaisdk.clients.rest.models.tenant_resource import TenantResource
from mtmaisdk.clients.rest.models.tenant_resource_limit import TenantResourceLimit
from mtmaisdk.clients.rest.models.tenant_resource_policy import TenantResourcePolicy
from mtmaisdk.clients.rest.models.tenant_step_run_queue_metrics import TenantStepRunQueueMetrics
from mtmaisdk.clients.rest.models.trigger_workflow_run_request import TriggerWorkflowRunRequest
from mtmaisdk.clients.rest.models.update_tenant_alert_email_group_request import UpdateTenantAlertEmailGroupRequest
from mtmaisdk.clients.rest.models.update_tenant_invite_request import UpdateTenantInviteRequest
from mtmaisdk.clients.rest.models.update_tenant_request import UpdateTenantRequest
from mtmaisdk.clients.rest.models.update_worker_request import UpdateWorkerRequest
from mtmaisdk.clients.rest.models.user import User
from mtmaisdk.clients.rest.models.user_change_password_request import UserChangePasswordRequest
from mtmaisdk.clients.rest.models.user_login_request import UserLoginRequest
from mtmaisdk.clients.rest.models.user_register_request import UserRegisterRequest
from mtmaisdk.clients.rest.models.user_tenant_memberships_list import UserTenantMembershipsList
from mtmaisdk.clients.rest.models.user_tenant_public import UserTenantPublic
from mtmaisdk.clients.rest.models.webhook_worker import WebhookWorker
from mtmaisdk.clients.rest.models.webhook_worker_create_request import WebhookWorkerCreateRequest
from mtmaisdk.clients.rest.models.webhook_worker_create_response import WebhookWorkerCreateResponse
from mtmaisdk.clients.rest.models.webhook_worker_created import WebhookWorkerCreated
from mtmaisdk.clients.rest.models.webhook_worker_list_response import WebhookWorkerListResponse
from mtmaisdk.clients.rest.models.webhook_worker_request import WebhookWorkerRequest
from mtmaisdk.clients.rest.models.webhook_worker_request_list_response import WebhookWorkerRequestListResponse
from mtmaisdk.clients.rest.models.webhook_worker_request_method import WebhookWorkerRequestMethod
from mtmaisdk.clients.rest.models.worker import Worker
from mtmaisdk.clients.rest.models.worker_label import WorkerLabel
from mtmaisdk.clients.rest.models.worker_list import WorkerList
from mtmaisdk.clients.rest.models.worker_runtime_info import WorkerRuntimeInfo
from mtmaisdk.clients.rest.models.worker_runtime_sdks import WorkerRuntimeSDKs
from mtmaisdk.clients.rest.models.workflow import Workflow
from mtmaisdk.clients.rest.models.workflow_concurrency import WorkflowConcurrency
from mtmaisdk.clients.rest.models.workflow_kind import WorkflowKind
from mtmaisdk.clients.rest.models.workflow_list import WorkflowList
from mtmaisdk.clients.rest.models.workflow_metrics import WorkflowMetrics
from mtmaisdk.clients.rest.models.workflow_run import WorkflowRun
from mtmaisdk.clients.rest.models.workflow_run_list import WorkflowRunList
from mtmaisdk.clients.rest.models.workflow_run_order_by_direction import WorkflowRunOrderByDirection
from mtmaisdk.clients.rest.models.workflow_run_order_by_field import WorkflowRunOrderByField
from mtmaisdk.clients.rest.models.workflow_run_shape import WorkflowRunShape
from mtmaisdk.clients.rest.models.workflow_run_status import WorkflowRunStatus
from mtmaisdk.clients.rest.models.workflow_run_triggered_by import WorkflowRunTriggeredBy
from mtmaisdk.clients.rest.models.workflow_runs_cancel_request import WorkflowRunsCancelRequest
from mtmaisdk.clients.rest.models.workflow_runs_metrics import WorkflowRunsMetrics
from mtmaisdk.clients.rest.models.workflow_runs_metrics_counts import WorkflowRunsMetricsCounts
from mtmaisdk.clients.rest.models.workflow_tag import WorkflowTag
from mtmaisdk.clients.rest.models.workflow_trigger_cron_ref import WorkflowTriggerCronRef
from mtmaisdk.clients.rest.models.workflow_trigger_event_ref import WorkflowTriggerEventRef
from mtmaisdk.clients.rest.models.workflow_triggers import WorkflowTriggers
from mtmaisdk.clients.rest.models.workflow_update_request import WorkflowUpdateRequest
from mtmaisdk.clients.rest.models.workflow_version import WorkflowVersion
from mtmaisdk.clients.rest.models.workflow_version_definition import WorkflowVersionDefinition
from mtmaisdk.clients.rest.models.workflow_version_meta import WorkflowVersionMeta
from mtmaisdk.clients.rest.models.workflow_workers_count import WorkflowWorkersCount



# coding: utf-8

"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from mtmaisdk.clients.rest.models.rate_limit_list import RateLimitList
from mtmaisdk.clients.rest.models.rate_limit_order_by_direction import RateLimitOrderByDirection
from mtmaisdk.clients.rest.models.rate_limit_order_by_field import RateLimitOrderByField

from mtmaisdk.clients.rest.api_client import ApiClient, RequestSerialized
from mtmaisdk.clients.rest.api_response import ApiResponse
from mtmaisdk.clients.rest.rest import RESTResponseType


class RateLimitsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def rate_limit_list(
        self,
        tenant: Annotated[str, Field(min_length=36, strict=True, max_length=36, description="The tenant id")],
        offset: Annotated[Optional[StrictInt], Field(description="The number to skip")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The number to limit by")] = None,
        search: Annotated[Optional[StrictStr], Field(description="The search query to filter for")] = None,
        order_by_field: Annotated[Optional[RateLimitOrderByField], Field(description="What to order by")] = None,
        order_by_direction: Annotated[Optional[RateLimitOrderByDirection], Field(description="The order direction")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RateLimitList:
        """List rate limits

        Lists all rate limits for a tenant.

        :param tenant: The tenant id (required)
        :type tenant: str
        :param offset: The number to skip
        :type offset: int
        :param limit: The number to limit by
        :type limit: int
        :param search: The search query to filter for
        :type search: str
        :param order_by_field: What to order by
        :type order_by_field: RateLimitOrderByField
        :param order_by_direction: The order direction
        :type order_by_direction: RateLimitOrderByDirection
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._rate_limit_list_serialize(
            tenant=tenant,
            offset=offset,
            limit=limit,
            search=search,
            order_by_field=order_by_field,
            order_by_direction=order_by_direction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RateLimitList",
            '400': "APIErrors",
            '403': "APIErrors",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def rate_limit_list_with_http_info(
        self,
        tenant: Annotated[str, Field(min_length=36, strict=True, max_length=36, description="The tenant id")],
        offset: Annotated[Optional[StrictInt], Field(description="The number to skip")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The number to limit by")] = None,
        search: Annotated[Optional[StrictStr], Field(description="The search query to filter for")] = None,
        order_by_field: Annotated[Optional[RateLimitOrderByField], Field(description="What to order by")] = None,
        order_by_direction: Annotated[Optional[RateLimitOrderByDirection], Field(description="The order direction")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RateLimitList]:
        """List rate limits

        Lists all rate limits for a tenant.

        :param tenant: The tenant id (required)
        :type tenant: str
        :param offset: The number to skip
        :type offset: int
        :param limit: The number to limit by
        :type limit: int
        :param search: The search query to filter for
        :type search: str
        :param order_by_field: What to order by
        :type order_by_field: RateLimitOrderByField
        :param order_by_direction: The order direction
        :type order_by_direction: RateLimitOrderByDirection
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._rate_limit_list_serialize(
            tenant=tenant,
            offset=offset,
            limit=limit,
            search=search,
            order_by_field=order_by_field,
            order_by_direction=order_by_direction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RateLimitList",
            '400': "APIErrors",
            '403': "APIErrors",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def rate_limit_list_without_preload_content(
        self,
        tenant: Annotated[str, Field(min_length=36, strict=True, max_length=36, description="The tenant id")],
        offset: Annotated[Optional[StrictInt], Field(description="The number to skip")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The number to limit by")] = None,
        search: Annotated[Optional[StrictStr], Field(description="The search query to filter for")] = None,
        order_by_field: Annotated[Optional[RateLimitOrderByField], Field(description="What to order by")] = None,
        order_by_direction: Annotated[Optional[RateLimitOrderByDirection], Field(description="The order direction")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List rate limits

        Lists all rate limits for a tenant.

        :param tenant: The tenant id (required)
        :type tenant: str
        :param offset: The number to skip
        :type offset: int
        :param limit: The number to limit by
        :type limit: int
        :param search: The search query to filter for
        :type search: str
        :param order_by_field: What to order by
        :type order_by_field: RateLimitOrderByField
        :param order_by_direction: The order direction
        :type order_by_direction: RateLimitOrderByDirection
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._rate_limit_list_serialize(
            tenant=tenant,
            offset=offset,
            limit=limit,
            search=search,
            order_by_field=order_by_field,
            order_by_direction=order_by_direction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RateLimitList",
            '400': "APIErrors",
            '403': "APIErrors",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _rate_limit_list_serialize(
        self,
        tenant,
        offset,
        limit,
        search,
        order_by_field,
        order_by_direction,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if tenant is not None:
            _path_params['tenant'] = tenant
        # process the query parameters
        if offset is not None:

            _query_params.append(('offset', offset))

        if limit is not None:

            _query_params.append(('limit', limit))

        if search is not None:

            _query_params.append(('search', search))

        if order_by_field is not None:

            _query_params.append(('orderByField', order_by_field.value))

        if order_by_direction is not None:

            _query_params.append(('orderByDirection', order_by_direction.value))

        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'cookieAuth',
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/tenants/{tenant}/rate-limits',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa
"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from mtmaisdk.clients.rest.models.api_error import APIError
from mtmaisdk.clients.rest.models.api_errors import APIErrors
from mtmaisdk.clients.rest.models.api_meta import APIMeta
from mtmaisdk.clients.rest.models.api_meta_auth import APIMetaAuth
from mtmaisdk.clients.rest.models.api_meta_integration import APIMetaIntegration
from mtmaisdk.clients.rest.models.api_meta_posthog import APIMetaPosthog
from mtmaisdk.clients.rest.models.api_resource_meta import APIResourceMeta
from mtmaisdk.clients.rest.models.api_token import APIToken
from mtmaisdk.clients.rest.models.accept_invite_request import AcceptInviteRequest
from mtmaisdk.clients.rest.models.bulk_create_event_request import BulkCreateEventRequest
from mtmaisdk.clients.rest.models.bulk_create_event_response import BulkCreateEventResponse
from mtmaisdk.clients.rest.models.cancel_event_request import CancelEventRequest
from mtmaisdk.clients.rest.models.create_api_token_request import CreateAPITokenRequest
from mtmaisdk.clients.rest.models.create_api_token_response import CreateAPITokenResponse
from mtmaisdk.clients.rest.models.create_event_request import CreateEventRequest
from mtmaisdk.clients.rest.models.create_pull_request_from_step_run import CreatePullRequestFromStepRun
from mtmaisdk.clients.rest.models.create_sns_integration_request import CreateSNSIntegrationRequest
from mtmaisdk.clients.rest.models.create_tenant_alert_email_group_request import CreateTenantAlertEmailGroupRequest
from mtmaisdk.clients.rest.models.create_tenant_invite_request import CreateTenantInviteRequest
from mtmaisdk.clients.rest.models.create_tenant_request import CreateTenantRequest
from mtmaisdk.clients.rest.models.cron_workflows import CronWorkflows
from mtmaisdk.clients.rest.models.cron_workflows_list import CronWorkflowsList
from mtmaisdk.clients.rest.models.cron_workflows_order_by_field import CronWorkflowsOrderByField
from mtmaisdk.clients.rest.models.event import Event
from mtmaisdk.clients.rest.models.event_data import EventData
from mtmaisdk.clients.rest.models.event_key_list import EventKeyList
from mtmaisdk.clients.rest.models.event_list import EventList
from mtmaisdk.clients.rest.models.event_order_by_direction import EventOrderByDirection
from mtmaisdk.clients.rest.models.event_order_by_field import EventOrderByField
from mtmaisdk.clients.rest.models.event_update_cancel200_response import EventUpdateCancel200Response
from mtmaisdk.clients.rest.models.event_workflow_run_summary import EventWorkflowRunSummary
from mtmaisdk.clients.rest.models.get_step_run_diff_response import GetStepRunDiffResponse
from mtmaisdk.clients.rest.models.job import Job
from mtmaisdk.clients.rest.models.job_run import JobRun
from mtmaisdk.clients.rest.models.job_run_status import JobRunStatus
from mtmaisdk.clients.rest.models.list_api_tokens_response import ListAPITokensResponse
from mtmaisdk.clients.rest.models.list_pull_requests_response import ListPullRequestsResponse
from mtmaisdk.clients.rest.models.list_sns_integrations import ListSNSIntegrations
from mtmaisdk.clients.rest.models.list_slack_webhooks import ListSlackWebhooks
from mtmaisdk.clients.rest.models.log_line import LogLine
from mtmaisdk.clients.rest.models.log_line_level import LogLineLevel
from mtmaisdk.clients.rest.models.log_line_list import LogLineList
from mtmaisdk.clients.rest.models.log_line_order_by_direction import LogLineOrderByDirection
from mtmaisdk.clients.rest.models.log_line_order_by_field import LogLineOrderByField
from mtmaisdk.clients.rest.models.pagination_response import PaginationResponse
from mtmaisdk.clients.rest.models.pull_request import PullRequest
from mtmaisdk.clients.rest.models.pull_request_state import PullRequestState
from mtmaisdk.clients.rest.models.queue_metrics import QueueMetrics
from mtmaisdk.clients.rest.models.rate_limit import RateLimit
from mtmaisdk.clients.rest.models.rate_limit_list import RateLimitList
from mtmaisdk.clients.rest.models.rate_limit_order_by_direction import RateLimitOrderByDirection
from mtmaisdk.clients.rest.models.rate_limit_order_by_field import RateLimitOrderByField
from mtmaisdk.clients.rest.models.recent_step_runs import RecentStepRuns
from mtmaisdk.clients.rest.models.reject_invite_request import RejectInviteRequest
from mtmaisdk.clients.rest.models.replay_event_request import ReplayEventRequest
from mtmaisdk.clients.rest.models.replay_workflow_runs_request import ReplayWorkflowRunsRequest
from mtmaisdk.clients.rest.models.replay_workflow_runs_response import ReplayWorkflowRunsResponse
from mtmaisdk.clients.rest.models.rerun_step_run_request import RerunStepRunRequest
from mtmaisdk.clients.rest.models.sns_integration import SNSIntegration
from mtmaisdk.clients.rest.models.scheduled_run_status import ScheduledRunStatus
from mtmaisdk.clients.rest.models.scheduled_workflows import ScheduledWorkflows
from mtmaisdk.clients.rest.models.scheduled_workflows_list import ScheduledWorkflowsList
from mtmaisdk.clients.rest.models.scheduled_workflows_order_by_field import ScheduledWorkflowsOrderByField
from mtmaisdk.clients.rest.models.semaphore_slots import SemaphoreSlots
from mtmaisdk.clients.rest.models.slack_webhook import SlackWebhook
from mtmaisdk.clients.rest.models.step import Step
from mtmaisdk.clients.rest.models.step_run import StepRun
from mtmaisdk.clients.rest.models.step_run_archive import StepRunArchive
from mtmaisdk.clients.rest.models.step_run_archive_list import StepRunArchiveList
from mtmaisdk.clients.rest.models.step_run_diff import StepRunDiff
from mtmaisdk.clients.rest.models.step_run_event import StepRunEvent
from mtmaisdk.clients.rest.models.step_run_event_list import StepRunEventList
from mtmaisdk.clients.rest.models.step_run_event_reason import StepRunEventReason
from mtmaisdk.clients.rest.models.step_run_event_severity import StepRunEventSeverity
from mtmaisdk.clients.rest.models.step_run_status import StepRunStatus
from mtmaisdk.clients.rest.models.tenant import Tenant
from mtmaisdk.clients.rest.models.tenant_alert_email_group import TenantAlertEmailGroup
from mtmaisdk.clients.rest.models.tenant_alert_email_group_list import TenantAlertEmailGroupList
from mtmaisdk.clients.rest.models.tenant_alerting_settings import TenantAlertingSettings
from mtmaisdk.clients.rest.models.tenant_invite import TenantInvite
from mtmaisdk.clients.rest.models.tenant_invite_list import TenantInviteList
from mtmaisdk.clients.rest.models.tenant_list import TenantList
from mtmaisdk.clients.rest.models.tenant_member import TenantMember
from mtmaisdk.clients.rest.models.tenant_member_list import TenantMemberList
from mtmaisdk.clients.rest.models.tenant_member_role import TenantMemberRole
from mtmaisdk.clients.rest.models.tenant_queue_metrics import TenantQueueMetrics
from mtmaisdk.clients.rest.models.tenant_resource import TenantResource
from mtmaisdk.clients.rest.models.tenant_resource_limit import TenantResourceLimit
from mtmaisdk.clients.rest.models.tenant_resource_policy import TenantResourcePolicy
from mtmaisdk.clients.rest.models.tenant_step_run_queue_metrics import TenantStepRunQueueMetrics
from mtmaisdk.clients.rest.models.trigger_workflow_run_request import TriggerWorkflowRunRequest
from mtmaisdk.clients.rest.models.update_tenant_alert_email_group_request import UpdateTenantAlertEmailGroupRequest
from mtmaisdk.clients.rest.models.update_tenant_invite_request import UpdateTenantInviteRequest
from mtmaisdk.clients.rest.models.update_tenant_request import UpdateTenantRequest
from mtmaisdk.clients.rest.models.update_worker_request import UpdateWorkerRequest
from mtmaisdk.clients.rest.models.user import User
from mtmaisdk.clients.rest.models.user_change_password_request import UserChangePasswordRequest
from mtmaisdk.clients.rest.models.user_login_request import UserLoginRequest
from mtmaisdk.clients.rest.models.user_register_request import UserRegisterRequest
from mtmaisdk.clients.rest.models.user_tenant_memberships_list import UserTenantMembershipsList
from mtmaisdk.clients.rest.models.user_tenant_public import UserTenantPublic
from mtmaisdk.clients.rest.models.webhook_worker import WebhookWorker
from mtmaisdk.clients.rest.models.webhook_worker_create_request import WebhookWorkerCreateRequest
from mtmaisdk.clients.rest.models.webhook_worker_create_response import WebhookWorkerCreateResponse
from mtmaisdk.clients.rest.models.webhook_worker_created import WebhookWorkerCreated
from mtmaisdk.clients.rest.models.webhook_worker_list_response import WebhookWorkerListResponse
from mtmaisdk.clients.rest.models.webhook_worker_request import WebhookWorkerRequest
from mtmaisdk.clients.rest.models.webhook_worker_request_list_response import WebhookWorkerRequestListResponse
from mtmaisdk.clients.rest.models.webhook_worker_request_method import WebhookWorkerRequestMethod
from mtmaisdk.clients.rest.models.worker import Worker
from mtmaisdk.clients.rest.models.worker_label import WorkerLabel
from mtmaisdk.clients.rest.models.worker_list import WorkerList
from mtmaisdk.clients.rest.models.worker_runtime_info import WorkerRuntimeInfo
from mtmaisdk.clients.rest.models.worker_runtime_sdks import WorkerRuntimeSDKs
from mtmaisdk.clients.rest.models.workflow import Workflow
from mtmaisdk.clients.rest.models.workflow_concurrency import WorkflowConcurrency
from mtmaisdk.clients.rest.models.workflow_kind import WorkflowKind
from mtmaisdk.clients.rest.models.workflow_list import WorkflowList
from mtmaisdk.clients.rest.models.workflow_metrics import WorkflowMetrics
from mtmaisdk.clients.rest.models.workflow_run import WorkflowRun
from mtmaisdk.clients.rest.models.workflow_run_list import WorkflowRunList
from mtmaisdk.clients.rest.models.workflow_run_order_by_direction import WorkflowRunOrderByDirection
from mtmaisdk.clients.rest.models.workflow_run_order_by_field import WorkflowRunOrderByField
from mtmaisdk.clients.rest.models.workflow_run_shape import WorkflowRunShape
from mtmaisdk.clients.rest.models.workflow_run_status import WorkflowRunStatus
from mtmaisdk.clients.rest.models.workflow_run_triggered_by import WorkflowRunTriggeredBy
from mtmaisdk.clients.rest.models.workflow_runs_cancel_request import WorkflowRunsCancelRequest
from mtmaisdk.clients.rest.models.workflow_runs_metrics import WorkflowRunsMetrics
from mtmaisdk.clients.rest.models.workflow_runs_metrics_counts import WorkflowRunsMetricsCounts
from mtmaisdk.clients.rest.models.workflow_tag import WorkflowTag
from mtmaisdk.clients.rest.models.workflow_trigger_cron_ref import WorkflowTriggerCronRef
from mtmaisdk.clients.rest.models.workflow_trigger_event_ref import WorkflowTriggerEventRef
from mtmaisdk.clients.rest.models.workflow_triggers import WorkflowTriggers
from mtmaisdk.clients.rest.models.workflow_update_request import WorkflowUpdateRequest
from mtmaisdk.clients.rest.models.workflow_version import WorkflowVersion
from mtmaisdk.clients.rest.models.workflow_version_definition import WorkflowVersionDefinition
from mtmaisdk.clients.rest.models.workflow_version_meta import WorkflowVersionMeta
from mtmaisdk.clients.rest.models.workflow_workers_count import WorkflowWorkersCount
